@@ -125,6 +125,7 @@ type Config interface {
 	kloader.Config
 	portforward.Config
 	IsMultiConfig() bool
+	JSONParseConfig() latestV1.JSONParseConfig
 }
 
 // NewDeployer returns a configured Deployer.  Returns an error if current version of helm is less than 3.0.0.
@@ -350,6 +351,7 @@ func (h *Deployer) Cleanup(ctx context.Context, out io.Writer, dryRun bool) erro
 		"DeployerType": "helm",
 	})
 
+	var errMsgs []string
 	for _, r := range h.Releases {
 		releaseName, err := util.ExpandEnvTemplateOrFail(r.Name, nil)
 		if err != nil {
@@ -372,9 +374,13 @@ func (h *Deployer) Cleanup(ctx context.Context, out io.Writer, dryRun bool) erro
 			args = append(args, "--namespace", namespace)
 		}
 		if err := h.exec(ctx, out, false, nil, args...); err != nil {
-			return deployerr.CleanupErr(err)
+			errMsgs = append(errMsgs, err.Error())
 		}
 	}
+
+	if len(errMsgs) != 0 {
+		return deployerr.CleanupErr(fmt.Errorf(strings.Join(errMsgs, "\n")))
+	}
 	return nil
 }
 
@@ -579,7 +585,7 @@ func (h *Deployer) deployRelease(ctx context.Context, out io.Writer, releaseName
 		return nil, userErr("get release", err)
 	}
 
-	artifacts := parseReleaseInfo(opts.namespace, bufio.NewReader(&b))
+	artifacts := parseReleaseManifests(opts.namespace, bufio.NewReader(&b))
 	return artifacts, nil
 }
 
