@@ -19,8 +19,14 @@ package runner
 import (
 	"context"
 	"io"
+
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build"
 )
 
-func (r *SkaffoldRunner) Prune(ctx context.Context, out io.Writer) error {
-	return r.builder.Prune(ctx, out)
+type Pruner struct {
+	build.Builder
+}
+
+func (r *Pruner) Prune(ctx context.Context, out io.Writer) error {
+	return r.Builder.Prune(ctx, out)
 }
